import axios from 'axios'

// 直接访问平台接口需要添加 userToke，多添加了也没有影响
function setHeadersInfo (config) {
  const geipToken = localStorage.getItem('geipToken')
  if (geipToken) {
    config.headers = config.headers || {}
    config.headers.userToken = geipToken
  }
  return config
}
function getErrorMsg (data) {
  return (
    data.errorMsg ||
    data.errMsg ||
    data.errorCode ||
    (data.data && data.data.errMsg) ||
    '请求出错'
  )
}

// 请求前进行拦截
axios.interceptors.request.use(
  config => {
    // 添加随机数
    const v = (+new Date()).toString(36)
    const split = config.url.indexOf('?') > 0 ? '&' : '?'
    config.url += `${split}__=${v}`
    return setHeadersInfo(config)
  },
  error => {
    alert(error.message)
    return Promise.reject(error)
  }
)

// 请求回来后统一拦截
axios.interceptors.response.use(
  res => {
    const data = res.data
    if (res.status === 200) {
      if (
        data.success === false ||
        (data.data && data.data.success === false)
      ) {
        const msg = getErrorMsg(data)
        alert(msg)
        return Promise.reject(res)
      }
      return Promise.resolve(res)
    } else {
      alert(data)
      return Promise.reject(res)
    }
  },
  error => {
    const status = error.request.status
    if (status === 403 || status === 401) {
      if (process.env.NODE_ENV !== 'development' && sessionStorage.getItem('debugger') !== 'true') {
        window.top.location.replace('/login')
      }
    }
    alert(error.message)
    return Promise.reject(error)
  }
)

const methods = ['get', 'post', 'put', 'patch', 'delete']
const http = {}
methods.forEach(method => {
  http[method] = function () {
    const args = Array.prototype.slice.call(arguments, 0)
    const p = new Promise((resolve, reject) => {
      axios[method]
        .apply(axios, args)
        .then(function ({ data }) {
          resolve(data)
        })
        .catch(error => {
          reject(error)
        })
    })
    return p
  }
})
export default http
